@@ -9,7 +9,7 @@
  */
 
 #include <sm/gen.h>
-SM_RCSID("@(#)$Id: main.c,v 8.64 2002/06/04 02:32:32 geir Exp $")
+SM_RCSID("@(#)$Id: main.c,v 8.64.2.8 2002/12/18 23:13:45 ca Exp $")
 
 #define _DEFINE	1
 #include "libmilter.h"
@@ -98,13 +98,13 @@ static int backlog = MI_SOMAXCONN;
 #if _FFR_SMFI_OPENSOCKET
 /*
 **  SMFI_OPENSOCKET -- try the socket setup to make sure we'll be
-**                     able to start up
+**		able to start up
 **
-**  	Parameters:
-**  		None.
+**	Parameters:
+**		None.
 **
-**  	Return:
-**  		MI_SUCCESS/MI_FAILURE
+**	Return:
+**		MI_SUCCESS/MI_FAILURE
 */
 
 int
@@ -236,6 +236,6 @@ smfi_main()
 	/* Startup the listener */
 	if (mi_listener(conn, dbg, smfi, timeout, backlog) != MI_SUCCESS)
 		r = MI_FAILURE;
-
 	return r;
 }
+
